==> mediawiki_1.31.7.orig.tar.gz: mediawiki-1.31.7/extensions/Renameuser/Renameuser.alias.php <==
<?php
/**
 * Aliases for Special:Renameuser
 *
 * @file
 * @ingroup Extensions
 */

$specialPageAliases = [];

/** English (English) */
$specialPageAliases['en'] = [
	'Renameuser' => [ 'RenameUser' ],
];

/** Arabic (العربية) */
$specialPageAliases['ar'] = [
	'Renameuser' => [ 'إعادة_تسمية_مستخدم' ],
];

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = [
	'Renameuser' => [ 'سمّى_تانى_يوزر' ],
];

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = [
	'Renameuser' => [ 'সদস্য_পুনৰ্নামকৰণ' ],
];

/** Avaric (авар) */
$specialPageAliases['av'] = [
	'Renameuser' => [ 'Переименовать_участника' ],
];

/** Bashkir (башҡортса) */
$specialPageAliases['ba'] = [
	'Renameuser' => [ 'RenameUser' ],
];

/** Bulgarian (български) */
$specialPageAliases['bg'] = [
	'Renameuser' => [ 'Преименуване' ],
];

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = [
	'Renameuser' => [ 'کارمرزوکی_نامی_ٹگلینتین' ],
];

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = [
	'Renameuser' => [ 'Ganti_ngaran_pamakai' ],
];

/** Bengali (বাংলা) */
$specialPageAliases['bn'] = [
	'Renameuser' => [ 'ব্যবহারকারী_নামান্তর', 'ব্যবহারকারী_পুনঃনামকরণ' ],
];

/** Breton (brezhoneg) */
$specialPageAliases['br'] = [
	'Renameuser' => [ 'AdenevelImplijer' ],
];

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = [
	'Renameuser' => [ 'PreimenovanjeKorisnika' ],
];

/** Catalan (català) */
$specialPageAliases['ca'] = [
	'Renameuser' => [ 'Reanomena_usuari' ],
];

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = [
	'Renameuser' => [ 'Декъашхочун_цӀе_хийца' ],
];

/** Czech (čeština) */
$specialPageAliases['cs'] = [
	'Renameuser' => [ 'Přejmenovat_uživatele' ],
];

/** German (Deutsch) */
$specialPageAliases['de'] = [
	'Renameuser' => [ 'Benutzer_umbenennen' ],
];

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = [
	'Renameuser' => [ 'NamedayışéKarberi' ],
];

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = [
	'Renameuser' => [ 'Wužywarja pśemjeniś' ],
];

/** Divehi (ދިވެހިބަސް) */
$specialPageAliases['dv'] = [
	'Renameuser' => [ 'މެމްބަރުގެ_ނަން_ބަދަލު_ކުރައްވާ' ],
];

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = [
	'Renameuser' => [ 'ΜετονομασίαΧρήστη' ],
];

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = [
	'Renameuser' => [ 'Alinomigi_uzanton' ],
];

/** Spanish (español) */
$specialPageAliases['es'] = [
	'Renameuser' => [ 'RenombrarUsuario', 'Renombrar_usuario', 'Cambiar_el_nombre_de_usuario' ],
];

/** Estonian (eesti) */
$specialPageAliases['et'] = [
	'Renameuser' => [ 'Kasutaja_ümbernimetamine' ],
];

/** Persian (فارسی) */
$specialPageAliases['fa'] = [
	'Renameuser' => [ 'تغییر_نام_کاربر' ],
];

/** Finnish (suomi) */
$specialPageAliases['fi'] = [
	'Renameuser' => [ 'Käyttäjätunnusten_nimeäminen' ],
];

/** French (français) */
$specialPageAliases['fr'] = [
	'Renameuser' => [ 'Renommer_utilisateur', 'RenommerUtilisateur' ],
];

/** Arpitan (arpetan) */
$specialPageAliases['frp'] = [
	'Renameuser' => [ 'Renomar_l\'usanciér', 'RenomarLUsanciér' ],
];

/** Galician (galego) */
$specialPageAliases['gl'] = [
	'Renameuser' => [ 'Renomear_o_usuario', 'Renomear_usuario', 'Renomear_a_usuaria', 'Renomear_usuaria' ],
];

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = [
	'Renameuser' => [ 'Benutzer_e_andre_Name_gee' ],
];

/** Hebrew (עברית) */
$specialPageAliases['he'] = [
	'Renameuser' => [ 'שינוי_שם_משתמש' ],
];

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = [
	'Renameuser' => [ 'सदस्यनाम_बदलें', 'सदस्य_नाम_बदलें' ],
];

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = [
	'Renameuser' => [ 'Preimenuj_suradnika' ],
];

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = [
	'Renameuser' => [ 'Wužiwarja_přemjenować' ],
];

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = [
	'Renameuser' => [ 'RenonmenItilizatè' ],
];

/** Hungarian (magyar) */
$specialPageAliases['hu'] = [
	'Renameuser' => [ 'Szerkesztő_átnevezése' ],
];

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = [
	'Renameuser' => [ 'Renominar_usator' ],
];

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = [
	'Renameuser' => [ 'Ganti_nama_pengguna', 'GantiNamaPengguna' ],
];

/** Italian (italiano) */
$specialPageAliases['it'] = [
	'Renameuser' => [ 'RinominaUtente' ],
];

/** Japanese (日本語) */
$specialPageAliases['ja'] = [
	'Renameuser' => [ '利用者名変更', '利用者名の変更' ],
];

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = [
	'Renameuser' => [ 'ប្ដូរឈ្មោះអ្នកប្រើប្រាស់' ],
];

/** Korean (한국어) */
$specialPageAliases['ko'] = [
	'Renameuser' => [ '이름바꾸기', '사용자이름바꾸기', '계정이름바꾸기' ],
];

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = [
	'Renameuser' => [ 'Metmaacher ömnänne', 'Medmaacher ömnänne', 'Metmaacher ömnenne', 'Medmaacher ömnenne', 'Metmaacher ömdäufe', 'Medmaacher ömdäufe' ],
];

/** Cornish (kernowek) */
$specialPageAliases['kw'] = [
	'Renameuser' => [ 'DashenwelDevnydhyer' ],
];

/** Latin (Latina) */
$specialPageAliases['la'] = [
	'Renameuser' => [ 'Usorem_renominare' ],
];

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = [
	'Renameuser' => [ 'Benotzer_ëmbenennen' ],
];

/** Macedonian (македонски) */
$specialPageAliases['mk'] = [
	'Renameuser' => [ 'ПреименувајКорисник' ],
];

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = [
	'Renameuser' => [ 'ഉപയോക്തൃപുനർനാമകരണം' ],
];

/** Marathi (मराठी) */
$specialPageAliases['mr'] = [
	'Renameuser' => [ 'सदस्यपुर्नामितकरा' ],
];

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = [
	'Renameuser' => [ 'Tukar_nama_pengguna' ],
];

/** Maltese (Malti) */
$specialPageAliases['mt'] = [
	'Renameuser' => [ 'BiddelIsemUtent' ],
];

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = [
	'Renameuser' => [ 'Gi_en_bruker_nytt_navn' ],
];

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = [
	'Renameuser' => [ 'Gebruker_herneumen' ],
];

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = [
	'Renameuser' => [ 'GebruikerHernoemen' ],
];

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = [
	'Renameuser' => [ 'Døyp_om_brukar' ],
];

/** Occitan (occitan) */
$specialPageAliases['oc'] = [
	'Renameuser' => [ 'TornarNomenarUtilizaire', 'Tornar nomenar Utilizaire' ],
];

/** Polish (polski) */
$specialPageAliases['pl'] = [
	'Renameuser' => [ 'Zmiana_nazwy_użytkownika' ],
];

/** Pashto (پښتو) */
$specialPageAliases['ps'] = [
	'Renameuser' => [ 'دکارونکي نوم بدلون' ],
];

/** Portuguese (português) */
$specialPageAliases['pt'] = [
	'Renameuser' => [ 'Alterar_nome_de_utilizador' ],
];

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = [
	'Renameuser' => [ 'Renomear_utilizador', 'Renomear_usuário' ],
];

/** Romanian (română) */
$specialPageAliases['ro'] = [
	'Renameuser' => [ 'Redenumire_utilizator' ],
];

/** Russian (русский) */
$specialPageAliases['ru'] = [
	'Renameuser' => [ 'Переименовать_участника' ],
];

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = [
	'Renameuser' => [ 'RinominaUtente' ],
];

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = [
	'Renameuser' => [ 'PremenovaťPoužívateľa' ],
];

/** Albanian (shqip) */
$specialPageAliases['sq'] = [
	'Renameuser' => [ 'RiemërtoPërdorues' ],
];

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = [
	'Renameuser' => [ 'ПреименујКорисника', 'Преименуј_корисника' ],
];

/** Swedish (svenska) */
$specialPageAliases['sv'] = [
	'Renameuser' => [ 'Användarnamnbyte' ],
];

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = [
	'Renameuser' => [ 'BadilishajinalaMtumiaji' ],
];

/** Thai (ไทย) */
$specialPageAliases['th'] = [
	'Renameuser' => [ 'เปลี่ยนชื่อผู้ใช้' ],
];

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = [
	'Renameuser' => [ 'Muling_pangalan_ang_tagagamit' ],
];

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = [
	'Renameuser' => [ 'KullanıcıAdınıDeğiştir', 'KullanıcıİsminiDeğiştir' ],
];

/** Ukrainian (українська) */
$specialPageAliases['uk'] = [
	'Renameuser' => [ 'Перейменувати_користувача', 'Переименовать_участника' ],
];

/** Urdu (اردو) */
$specialPageAliases['ur'] = [
	'Renameuser' => [ 'تبدیلی_نام' ],
];

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = [
	'Renameuser' => [ 'Đổi_tên_thành_viên', 'Đổi_tên_người_dùng' ],
];

/** Chinese (中文) */
$specialPageAliases['zh'] = [
	'Renameuser' => [ '重命名用户', '重新命名用户', '重新命名用戶', '重新命名使用者' ],
];

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = [
	'Renameuser' => [ '重命名用户' ],
];

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = [
	'Renameuser' => [ '重新命名使用者' ],
];

==> mediawiki_1.35.13.orig.tar.gz: mediawiki-1.35.13/extensions/Renameuser/Renameuser.alias.php <==
<?php
/**
 * Aliases for Special:Renameuser
 *
 * @file
 * @ingroup Extensions
 */

$specialPageAliases = [];

/** English (English) */
$specialPageAliases['en'] = [
	'Renameuser' => [ 'RenameUser' ],
];

/** Arabic (العربية) */
$specialPageAliases['ar'] = [
	'Renameuser' => [ 'إعادة_تسمية_مستخدم' ],
];

/** Egyptian Arabic (مصرى) */
$specialPageAliases['arz'] = [
	'Renameuser' => [ 'سمّى_تانى_يوزر' ],
];

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = [
	'Renameuser' => [ 'সদস্য_পুনৰ্নামকৰণ' ],
];

/** Avaric (авар) */
$specialPageAliases['av'] = [
	'Renameuser' => [ 'Переименовать_участника' ],
];

/** Bashkir (башҡортса) */
$specialPageAliases['ba'] = [
	'Renameuser' => [ 'RenameUser' ],
];

/** Bulgarian (български) */
$specialPageAliases['bg'] = [
	'Renameuser' => [ 'Преименуване' ],
];

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = [
	'Renameuser' => [ 'کارمرزوکی_نامی_ٹگلینتین' ],
];

/** Banjar (Bahasa Banjar) */
$specialPageAliases['bjn'] = [
	'Renameuser' => [ 'Ganti_ngaran_pamakai' ],
];

/** Bengali (বাংলা) */
$specialPageAliases['bn'] = [
	'Renameuser' => [ 'ব্যবহারকারী_নামান্তর', 'ব্যবহারকারী_পুনঃনামকরণ' ],
];

/** Breton (brezhoneg) */
$specialPageAliases['br'] = [
	'Renameuser' => [ 'AdenevelImplijer' ],
];

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = [
	'Renameuser' => [ 'PreimenovanjeKorisnika' ],
];

/** Catalan (català) */
$specialPageAliases['ca'] = [
	'Renameuser' => [ 'Reanomena_usuari' ],
];

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = [
	'Renameuser' => [ 'Декъашхочун_цӀе_хийца' ],
];

/** Czech (čeština) */
$specialPageAliases['cs'] = [
	'Renameuser' => [ 'Přejmenovat_uživatele' ],
];

/** German (Deutsch) */
$specialPageAliases['de'] = [
	'Renameuser' => [ 'Benutzer_umbenennen' ],
];

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = [
	'Renameuser' => [ 'NamedayışéKarberi' ],
];

/** Lower Sorbian (dolnoserbski) */
$specialPageAliases['dsb'] = [
	'Renameuser' => [ 'Wužywarja pśemjeniś' ],
];

/** Divehi (ދިވެހިބަސް) */
$specialPageAliases['dv'] = [
	'Renameuser' => [ 'މެމްބަރުގެ_ނަން_ބަދަލު_ކުރައްވާ' ],
];

/** Greek (Ελληνικά) */
$specialPageAliases['el'] = [
	'Renameuser' => [ 'ΜετονομασίαΧρήστη' ],
];

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = [
	'Renameuser' => [ 'Alinomigi_uzanton' ],
];

/** Spanish (español) */
$specialPageAliases['es'] = [
	'Renameuser' => [ 'RenombrarUsuario', 'Renombrar_usuario', 'Cambiar_el_nombre_de_usuario' ],
];

/** Estonian (eesti) */
$specialPageAliases['et'] = [
	'Renameuser' => [ 'Kasutaja_ümbernimetamine' ],
];

/** Persian (فارسی) */
$specialPageAliases['fa'] = [
	'Renameuser' => [ 'تغییر_نام_کاربر' ],
];

/** Finnish (suomi) */
$specialPageAliases['fi'] = [
	'Renameuser' => [ 'Käyttäjätunnusten_nimeäminen' ],
];

/** French (français) */
$specialPageAliases['fr'] = [
	'Renameuser' => [ 'Renommer_utilisateur', 'RenommerUtilisateur' ],
];

/** Arpitan (arpetan) */
$specialPageAliases['frp'] = [
	'Renameuser' => [ 'Renomar_l\'usanciér', 'RenomarLUsanciér' ],
];

/** Galician (galego) */
$specialPageAliases['gl'] = [
	'Renameuser' => [ 'Renomear_o_usuario', 'Renomear_usuario', 'Renomear_a_usuaria', 'Renomear_usuaria' ],
];

/** Swiss German (Alemannisch) */
$specialPageAliases['gsw'] = [
	'Renameuser' => [ 'Benutzer_e_andre_Name_gee' ],
];

/** Hebrew (עברית) */
$specialPageAliases['he'] = [
	'Renameuser' => [ 'שינוי_שם_משתמש' ],
];

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = [
	'Renameuser' => [ 'सदस्यनाम_बदलें', 'सदस्य_नाम_बदलें' ],
];

/** Croatian (hrvatski) */
$specialPageAliases['hr'] = [
	'Renameuser' => [ 'Preimenuj_suradnika' ],
];

/** Upper Sorbian (hornjoserbsce) */
$specialPageAliases['hsb'] = [
	'Renameuser' => [ 'Wužiwarja_přemjenować' ],
];

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = [
	'Renameuser' => [ 'RenonmenItilizatè' ],
];

/** Hungarian (magyar) */
$specialPageAliases['hu'] = [
	'Renameuser' => [ 'Szerkesztő_átnevezése' ],
];

/** Interlingua (interlingua) */
$specialPageAliases['ia'] = [
	'Renameuser' => [ 'Renominar_usator' ],
];

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = [
	'Renameuser' => [ 'Ganti_nama_pengguna', 'GantiNamaPengguna' ],
];

/** Italian (italiano) */
$specialPageAliases['it'] = [
	'Renameuser' => [ 'RinominaUtente' ],
];

/** Japanese (日本語) */
$specialPageAliases['ja'] = [
	'Renameuser' => [ '利用者名変更', '利用者名の変更' ],
];

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = [
	'Renameuser' => [ 'ប្ដូរឈ្មោះអ្នកប្រើប្រាស់' ],
];

/** Korean (한국어) */
$specialPageAliases['ko'] = [
	'Renameuser' => [ '이름바꾸기', '사용자이름바꾸기', '계정이름바꾸기' ],
];

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = [
	'Renameuser' => [ 'Metmaacher ömnänne', 'Medmaacher ömnänne', 'Metmaacher ömnenne', 'Medmaacher ömnenne', 'Metmaacher ömdäufe', 'Medmaacher ömdäufe' ],
];

/** Cornish (kernowek) */
$specialPageAliases['kw'] = [
	'Renameuser' => [ 'DashenwelDevnydhyer' ],
];

/** Latin (Latina) */
$specialPageAliases['la'] = [
	'Renameuser' => [ 'Usorem_renominare' ],
];

/** Luxembourgish (Lëtzebuergesch) */
$specialPageAliases['lb'] = [
	'Renameuser' => [ 'Benotzer_ëmbenennen' ],
];

/** Macedonian (македонски) */
$specialPageAliases['mk'] = [
	'Renameuser' => [ 'ПреименувајКорисник' ],
];

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = [
	'Renameuser' => [ 'ഉപയോക്തൃപുനർനാമകരണം' ],
];

/** Marathi (मराठी) */
$specialPageAliases['mr'] = [
	'Renameuser' => [ 'सदस्यपुर्नामितकरा' ],
];

/** Malay (Bahasa Melayu) */
$specialPageAliases['ms'] = [
	'Renameuser' => [ 'Tukar_nama_pengguna' ],
];

/** Maltese (Malti) */
$specialPageAliases['mt'] = [
	'Renameuser' => [ 'BiddelIsemUtent' ],
];

/** Norwegian Bokmål (norsk bokmål) */
$specialPageAliases['nb'] = [
	'Renameuser' => [ 'Gi_en_bruker_nytt_navn' ],
];

/** Low Saxon (Netherlands) (Nedersaksies) */
$specialPageAliases['nds-nl'] = [
	'Renameuser' => [ 'Gebruker_herneumen' ],
];

/** Dutch (Nederlands) */
$specialPageAliases['nl'] = [
	'Renameuser' => [ 'GebruikerHernoemen' ],
];

/** Norwegian Nynorsk (norsk nynorsk) */
$specialPageAliases['nn'] = [
	'Renameuser' => [ 'Døyp_om_brukar' ],
];

/** Occitan (occitan) */
$specialPageAliases['oc'] = [
	'Renameuser' => [ 'TornarNomenarUtilizaire', 'Tornar nomenar Utilizaire' ],
];

/** Polish (polski) */
$specialPageAliases['pl'] = [
	'Renameuser' => [ 'Zmiana_nazwy_użytkownika' ],
];

/** Pashto (پښتو) */
$specialPageAliases['ps'] = [
	'Renameuser' => [ 'دکارونکي نوم بدلون' ],
];

/** Portuguese (português) */
$specialPageAliases['pt'] = [
	'Renameuser' => [ 'Alterar_nome_de_utilizador' ],
];

/** Brazilian Portuguese (português do Brasil) */
$specialPageAliases['pt-br'] = [
	'Renameuser' => [ 'Renomear_utilizador', 'Renomear_usuário' ],
];

/** Romanian (română) */
$specialPageAliases['ro'] = [
	'Renameuser' => [ 'Redenumire_utilizator' ],
];

/** Russian (русский) */
$specialPageAliases['ru'] = [
	'Renameuser' => [ 'Переименовать_участника' ],
];

/** Sicilian (sicilianu) */
$specialPageAliases['scn'] = [
	'Renameuser' => [ 'RinominaUtente' ],
];

/** Slovak (slovenčina) */
$specialPageAliases['sk'] = [
	'Renameuser' => [ 'PremenovaťPoužívateľa' ],
];

/** Albanian (shqip) */
$specialPageAliases['sq'] = [
	'Renameuser' => [ 'RiemërtoPërdorues' ],
];

/** Serbian (Cyrillic script) (српски (ћирилица)‎) */
$specialPageAliases['sr-ec'] = [
	'Renameuser' => [ 'ПреименујКорисника', 'Преименуј_корисника' ],
];

/** Serbian (Latin script) (srpski (latinica)‎) */
$specialPageAliases['sr-el'] = [
	'Renameuser' => [ 'PreimenujKorisnika', 'Preimenuj_korisnika' ],
];

/** Swedish (svenska) */
$specialPageAliases['sv'] = [
	'Renameuser' => [ 'Användarnamnbyte' ],
];

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = [
	'Renameuser' => [ 'BadilishajinalaMtumiaji' ],
];

/** Thai (ไทย) */
$specialPageAliases['th'] = [
	'Renameuser' => [ 'เปลี่ยนชื่อผู้ใช้' ],
];

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = [
	'Renameuser' => [ 'Muling_pangalan_ang_tagagamit' ],
];

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = [
	'Renameuser' => [ 'KullanıcıAdınıDeğiştir', 'KullanıcıİsminiDeğiştir' ],
];

/** Ukrainian (українська) */
$specialPageAliases['uk'] = [
	'Renameuser' => [ 'Перейменувати_користувача', 'Переименовать_участника' ],
];

/** Urdu (اردو) */
$specialPageAliases['ur'] = [
	'Renameuser' => [ 'تبدیلی_نام' ],
];

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = [
	'Renameuser' => [ 'Đổi_tên_thành_viên', 'Đổi_tên_người_dùng' ],
];

/** Chinese (中文) */
$specialPageAliases['zh'] = [
	'Renameuser' => [ '重命名用户', '重新命名用户', '重新命名用戶', '重新命名使用者' ],
];

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = [
	'Renameuser' => [ '重命名用户' ],
];

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = [
	'Renameuser' => [ '重新命名使用者' ],
];
